@@ -16,8 +16,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#ifndef __MESSAGELIST_PANE_H__
-#define __MESSAGELIST_PANE_H__
+#ifndef MESSAGELIST_PANE_H
+#define MESSAGELIST_PANE_H
 
 #include <messagelist/enums.h>
 #include <messagelist/view.h>
@@ -26,7 +26,6 @@
 
 #include <kmime/kmime_message.h>
 #include <collection.h>
-#include <item.h>
 #include <messagelist_export.h>
 #include <AkonadiCore/Item>
 
@@ -35,14 +34,11 @@ class QAbstractItemModel;
 class QItemSelectionModel;
 class QItemSelection;
 
-namespace KPIM
-{
+namespace KPIM {
 class MessageStatus;
 }
 
-namespace MessageList
-{
-
+namespace MessageList {
 class Widget;
 class StorageModel;
 
@@ -65,7 +61,7 @@ public:
     * Create a Pane wrapping the specified model and selection.
     */
     explicit Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = nullptr);
-    ~Pane();
+    ~Pane() override;
 
     virtual MessageList::StorageModel *createStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent);
 
@@ -159,10 +155,7 @@ public:
     * If loop is true then the "next" algorithm will restart from the beginning
     * of the list if the end is reached, otherwise it will just stop returning false.
     */
-    bool selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                               MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                               bool centerItem,
-                               bool loop);
+    bool selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
 
     /**
     * Selects the previous message item in the view.
@@ -177,10 +170,7 @@ public:
     * If loop is true then the "previous" algorithm will restart from the end
     * of the list if the beginning is reached, otherwise it will just stop returning false.
     */
-    bool selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                   MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                   bool centerItem,
-                                   bool loop);
+    bool selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
 
     /**
     * Focuses the next message item in the view without actually selecting it.
@@ -294,10 +284,7 @@ public:
     * If includeCollapsedChildren is true then the children of the selected but
     * collapsed items are also included in the stats
     */
-    bool getSelectionStats(Akonadi::Item::List &selectedItems,
-                           Akonadi::Item::List &selectedVisibleItems,
-                           bool *allSelectedBelongToSameThread,
-                           bool includeCollapsedChildren = true) const;
+    bool getSelectionStats(Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren = true) const;
     /**
     * Deletes the persistent set pointed by the specified reference.
     * If the set does not exist anymore, nothing happens.
@@ -360,11 +347,8 @@ public:
     * like "loading..."
     */
     void setCurrentFolder(
-        const Akonadi::Collection &fld,
-        bool preferEmptyTab = false,
-        MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected,
-        const QString &overrideLabel = QString()
-    );
+        const Akonadi::Collection &fld, bool preferEmptyTab = false, MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected,
+        const QString &overrideLabel = QString());
 
     void resetModelStorage();
 
@@ -383,6 +367,9 @@ public:
     void populateStatusFilterCombo();
 
     Core::QuickSearchLine::SearchOptions currentOptions() const;
+
+    Akonadi::Collection currentFolder() const;
+
 public Q_SLOTS:
     /**
     * Selects all the items in the current folder.
@@ -441,31 +428,22 @@ Q_SIGNALS:
     */
     void currentTabChanged();
 
+    void forceLostFocus();
+
 private:
     void restoreHeaderSettings(int index);
     void readConfig(bool restoreSession);
 
     Q_PRIVATE_SLOT(d, void onSelectionChanged(const QItemSelection &, const QItemSelection &))
-    Q_PRIVATE_SLOT(d, void onNewTabClicked())
-    Q_PRIVATE_SLOT(d, void onCloseTabClicked())
-    Q_PRIVATE_SLOT(d, void activateTab())
-    Q_PRIVATE_SLOT(d, void moveTabLeft())
-    Q_PRIVATE_SLOT(d, void moveTabRight())
-    Q_PRIVATE_SLOT(d, void activateNextTab())
-    Q_PRIVATE_SLOT(d, void activatePreviousTab())
     Q_PRIVATE_SLOT(d, void closeTab(QWidget *))
-    Q_PRIVATE_SLOT(d, void onCurrentTabChanged())
-    Q_PRIVATE_SLOT(d, void onTabContextMenuRequest(const QPoint &))
     Q_PRIVATE_SLOT(d, void updateTabControls())
     Q_PRIVATE_SLOT(d, void changeQuicksearchVisibility(bool))
-    Q_PRIVATE_SLOT(d, void slotTabCloseRequested(int index))
 
-    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
     class Private;
     Private *const d;
 };
-
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_PANE_H__
+#endif //!__MESSAGELIST_PANE_H
